#!/bin/bash
#
# NAME
# ----
# - xymon_nut_out-voltage.sh
#
# DESCRIPTION
# -----------
# - External client script to poll a NUT server for a UPS's AC output
#   voltage and report back to a Xymon Monitoring Server
#
# - The most current version of this script may be  
#   found at http://www.revpol.com/xymon_nut_scripts
#
# - Instructions to integrate the output of this script to be monitored
#   and graphed by a Xymon server may also be found at the above URL
#
# - If you find this script useful, I'd love to know. Send me an email!
#
# Author
# ------
# William A. Arlofski  
# Reverse Polarity, LLC
# 860-824-2433 Office   
# http://www.revpol.com/
# 
# HISTORY
# -------
# - 20080319 - Initial version release
# - 20100613 - Major overhauls including error checking on data
#              returned by the upsc command
# - 20100728 - Removed all local system binary definitions since they are
#              defined in hobbitserver.cfg which is sourced before external 
#              scripts are called. $ECHO was also removed and all calls to it
#              where changed to 'echo' since most shells have a built-in echo
#            - Modified the datanopoint assignment to take into account UPSes
#              that report values with more than one decimal point of precision
#            - Thanks to Josh Luthman for pointing out what a pain it was to 
#              make those assignments in each script which led me to remember
#              they are already defined in hobbitserver.cfg. :)
#
###############################################################################
#
# Copyright (C) 2010 William A. Arlofski - waa-at-revpol-dot-com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# or visit http://www.gnu.org/licenses/gpl.txt
#
###############################################################################

# ----------------------------
# Define local system binaries
# ----------------------------
UPSC="/usr/bin/upsc"

# ----------------------
# Set up Xymon and
# other script variables
# ----------------------
COLUMN="out-voltage"
COLOR="green"
MSG=""

nutserver="host.example.com"
upslist="apc1000"
datatest="output\.voltage:"
yellowtest="115"
redtest="109"

# Add an administrative message to the top of the report page
# -----------------------------------------------------------
ADMINMSG="- AC output voltage for $upslist on $nutserver"

# ---------------------------------------------------------------------------
# Nothing should need to be modified below this line
# ---------------------------------------------------------------------------

# Query information from the NUT server for each UPS
# it is physically connected to and monitoring
# --------------------------------------------------
for ups in $upslist; do
  # Query the NUT server for the AC output voltage
  # ----------------------------------------------
  data=`"$UPSC" "$ups"@"$nutserver" 2>&1 | "$GREP" "$datatest" | "$CUT" -d' ' -f2`

  # If there is a problem querying the NUT server assign the COLOR
  # variable and send an appropriate message to the Xymon server
  # --------------------------------------------------------------
  if [ -z "$data" ]; then
    COLOR="yellow"
    MSG="Problem retreiving data for $upslist from $nutserver"
    
    else

      # Strip everything past the decimal so 118.1 becomes 118
      # ------------------------------------------------------
      datanopoint=`echo "$data" | "$SED" -e 's/\.[0-9]\{1,2\}//'`

      # Determine if the voltage is too low and assign
      # appropriate value to the COLOR variable
      # ----------------------------------------------
      if [ "$datanopoint" -le "$redtest" ]; then
        COLOR="red"
         elif [ "$datanopoint" -le "$yellowtest" ]; then
          COLOR="yellow"
     fi

     # Assign the UPS and it's value to the MSG variable
     # -------------------------------------------------
     MSG="${MSG}
     &$COLOR $ups : $data"

  fi
done

# Prepend the ADMINMSG to the message 
# to be returned to the Xymon server
#------------------------------------
MSG="$ADMINMSG

${MSG}"


# Report status to Xymon Server
# -----------------------------
$BB $BBDISP "status $MACHINE.$COLUMN $COLOR `"$DATE"`

${MSG}
"
exit 0
